Make the default java_sdk_library dist_group "unknown"

Change the default dist_group from "android" to "unknown" to prevent
accidentally including java_sdk_library stubs that do not set
dist_group or owner in the public SDK.

Bug: 186723288
Test: TestJavaSdkLibraryDist
Change-Id: I9aae2a16254ac1a8d444acfa63bc571d1ef4b045
diff --git a/java/sdk_library.go b/java/sdk_library.go
index ecf2b1a..1936bf5 100644
--- a/java/sdk_library.go
+++ b/java/sdk_library.go
@@ -458,7 +458,7 @@
 	Dist_stem *string
 
 	// The subdirectory for the artifacts that are copied to the dist directory.  If not specified
 	// then defaults to "android".  Should be set to "android" for anything that should be published
 	// in the public Android SDK.
 	Dist_group *string
 
@@ -1240,8 +1240,7 @@
 	if owner := module.ModuleBase.Owner(); owner != "" {
 		return owner
 	}
-	// TODO(b/186723288): Make this "unknown".
-	return "android"
+	return "unknown"
 }
 
 func (module *SdkLibrary) latestApiFilegroupName(apiScope *apiScope) string {
@@ -458,7 +458,7 @@
 
 	// The subdirectory for the artifacts that are copied to the dist directory.  If not specified
-	// then defaults to "android".  Should be set to "android" for anything that should be published
+	// then defaults to "unknown".  Should be set to "android" for anything that should be published
 	// in the public Android SDK.
 	Dist_group *string